function p = polyget(A)
%  *** To create a polynomial coefficient vector from polynomial factors
%
%    For given
%        p(x) = PROD[i=1,m]{SUM[j=2,n+2]{(A(i,j)*x^(j-2))^A(i,1)}}
%    we shall get
%        p(x) = SUM[s=1,N+1]{p(s)^(N+1-s)}
%
%
%    For example
%    If  
%       p(x) = (x-4)^5 * (3x^6-7x^3+5x+2)^2 * (x^3+8)^3 * x^2
%    or
%          A = [ 5    -4   1   0   0   0   0   0  
%                2     2   5   0  -7   0   0   3
%                3     8   0   0   1   0   0   0
%                1     0   0   1   0   0   0   0  ]
%    then from
%           p = polyget(A)  
%    we get
%           p = [ 9  -180  1440  -5586  .... -7864320  -209715   0   0 ]
%    or  
%        p(x) = 9x^28-180x^27+1440x^26-5586x^25+ ... -7864320x^3-2097152x^2.
%
%
%    This routine is mainly to be used for creating test polynomials to
%       (a) determine the polynomial GCD of a pair of polynomials,
%       (b) find the roots with muliplicities of a given polynomial.
%
%    References in MATLAB Central:
%       (1) "GCD of polynomials,"  
%            File ID 20859,  12 Apr 2009
%       (2) "Factorization of a polynomial with multiple roots," 
%            File ID: 20867, 27 Jul 2008
%       (3) "Multiple-roots polynomial solved by partial fraction expansion,"
%            File ID: 22375, 10 Dec 2008       
%
%    F C Chang   04/25/09
%
%
%function p = polyget(A)
%  *** A poly coef vector from sub-poly factors ***

       p = 1;
   for i = 1:length(A(:,1)),
       q = 1;
   for j = 1:A(i,1),
       q = conv(q,A(i,max(find(A(i,:))):-1:2));
   end;
       p = conv(p,q);
   end;
